import os
from pathlib import Path

import typer

app = typer.Typer()


@app.command()
def count_lines(filepath: str):
    print("file", "|", "line count")
    print("-" * 15)
    for file in os.listdir(filepath):
        if os.path.isfile(file) and (file.endswith(".txt") or file.endswith(".csv")):
            with open(Path(filepath) / file, encoding="utf-8") as f:
                print(file, "|", len(f.readlines()))


if __name__ == "__main__":
    app()



import setuptools


setuptools.setup(
    name="file lines counter",
    version="0.0.3",
    author="me",
    author_email="aa@example.com",
    description=("lines  counter"),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["typer"],
    packages=setuptools.find_packages(),
    python_requires=">=3.7",
    entry_points={
        "console_scripts": [
            "count = src.wc_util:app",
        ]
    },
)
